# Tyk Dashboard

Tyk Dashboard enables the management of the Tyk API Gateway server via an interface and processes analytics data for
reporting.

See [the docs](https://tyk.io/docs) and the [dev env project](https://github.com/TykTechnologies/tyk-develop-env) for
installation and configuration.

## Git submodule `webclient`

The `webclient` directory in the root of this project is a git submodule to pull in the
[`tyk-analytics-ui`](https://github.com/TykTechnologies/tyk-analytics-ui) project.

After cloning this project for the first time, initialise the submodule like so:

``` shell
$ git submodule init
Submodule 'webclient' (https://git@github.com/TykTechnologies/tyk-analytics-ui.git) registered for path 'webclient'
```

When there are new changes in the `tyk-analytics-ui` project, pull them into your local with the following command:

``` shell
$ git submodule update
Submodule path 'webclient': checked out '678157a8c367cf7474b84235c019c79a5e6a2ac6'
```

# Automation status

| Workflow | Status |
|----------|--------|
| Asset building | ![Build assets](https://github.com/TykTechnologies/tyk-analytics/workflows/Build%20assets/badge.svg?branch=master) |
| Tyk version | ![Update go.mod](https://github.com/TykTechnologies/tyk-analytics/workflows/Update%20go.mod/badge.svg?branch=master) |

## Testing goreleaser locally
Since the code requires cgo, the goreleaser configuration is split into per-architecture builds. Cross compiler toolchains are required to build. To run goreleaser locally, in the root of the repo,

``` shell
% docker run --rm --privileged -e CGO_ENABLED=1 -e GO111MODULE=on -e GITHUB_TOKEN=sekret -e PKG_SIGNING_KEY="$(<~src/rpmsign/tyk.io.signing.key)" \
       -e NFPM_STD_PASSPHRASE=sekret -e NFPM_PAYG_PASSPHRASE=sekret -e GPG_FINGERPRINT=12B5D62C28F57592D1575BD51ED14C59E37DAC20 \
       -v /var/run/docker.sock:/var/run/docker.sock -v ~/.docker/config.json:/root/.docker/config.json \
       -v `pwd`:/go/src/github.com/TykTechnologies/tyk-analytics \
       -w /go/src/github.com/TykTechnologies/tyk-analytics \
       tykio/golang-cross:1.15.8 bash -c 'bin/unlock-agent.sh && goreleaser --rm-dist'
```

### Setting up the toolchain
[tykio/golang-cross](https://github.com/TykTechnologies/golang-cross) contains the cross-compiler toolchains to _build_ the debs, rpms, and binary tarballs.

To build multi-arch docker manifests, use buildx and docker-ce. The experimental flag [needs to be enabled](https://docs.docker.com/engine/reference/commandline/dockerd/#description) in the docker installation. Then [setup buildx](https://github.com/docker/buildx#getting-started) and ensure that you have it configured for `linux/arm64` and `linux/amd64` platforms.

The same infrastructure is used in CI.
